@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- * Copyright © 2012-2014 James Hunt <james.hunt@ubuntu.com>.
+ * Copyright © 2012-2015 James Hunt <jamesodhunt@ubuntu.com>.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,9 @@
 #define PROCENV_H
 
 /* for dl_iterate_phdr(3) */
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
+#endif
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -97,12 +99,13 @@
  *
  * XXX: must be updated for every change.
  *
+ * VERSION 1:
+ *   - Original format (up to procenv 0.27).
  * VERSION 2:
  *   - Added --memory.
  *   - Expanded --cpu.
  *   - Added missing --cpu to default output.
  *   - Moved memory page size from --misc to --memory.
- *
  * VERSION 3:
  *   - --fds: Added Capsicum capabilities for FreeBSD (alas this version
  *     is a NOP for non-BSD platforms).
@@ -121,8 +124,10 @@
  * VERSION 8:
  *   - --memory: Added NUMA API version.
  *   - --shared-memory: Added swap_attempts and swap_successes.
+ * VERSION 9:
+ *   - --meta now includes a 'build-type' field.
  **/
-#define PROCENV_FORMAT_VERSION 8
+#define PROCENV_FORMAT_VERSION 9
 
 #define PROCENV_DEFAULT_TEXT_SEPARATOR ": "
 
@@ -444,18 +449,21 @@ int cap_get_bound (cap_value_t cap);
 /* FIXME: gettext */
 #define _(str) str
 
-#define YES_STR              _("yes")
-#define NO_STR               _("no")
-#define NON_STR              _("non")
-#define NA_STR               _("n/a")
-#define UNKNOWN_STR          _("unknown")
-#define MAX_STR              _(" (max)")
-#define DEFINED_STR          _("defined")
-#define NOT_DEFINED_STR      _("not defined")
-#define NOT_IMPLEMENTED_STR  _("[not implemented]")
-#define BIG_STR              _("big")
-#define LITTLE_STR           _("little")
-#define PRIVILEGED_STR       _("privileged")
+#define YES_STR                      _("yes")
+#define NO_STR                       _("no")
+#define NON_STR                      _("non")
+#define NA_STR                       _("n/a")
+#define UNKNOWN_STR                  _("unknown")
+#define MAX_STR                      _(" (max)")
+#define DEFINED_STR                  _("defined")
+#define NOT_DEFINED_STR              _("not defined")
+#define NOT_IMPLEMENTED_STR          _("[not implemented]")
+#define BIG_STR                      _("big")
+#define LITTLE_STR                   _("little")
+#define PRIVILEGED_STR               _("privileged")
+#define SUPPRESSED_STR               _("[suppressed]")
+#define BUILD_TYPE_STD_STR           _("standard")
+#define BUILD_TYPE_REPRODUCIBLE_STR  _("reproducible")
 
 #if defined (PROCENV_BSD)
 		/* SIGTHL is hidden by default */
@@ -468,7 +476,7 @@ int cap_get_bound (cap_value_t cap);
 #define DF_BLOCK_SIZE 1024
 
 /* Default character to use for indent */
-#define DEFAULT_INDENT_CHAR ' '
+#define DEFAULT_INDENT_CHAR " "
 
 /* If an indent is required, use this many INDENT_CHARs by default */
 #define DEFAULT_INDENT_AMOUNT 2
@@ -518,6 +526,7 @@ int cap_get_bound (cap_value_t cap);
 
 #define die(...) \
 { \
+	output = OUTPUT_STDERR; \
 	_message ("ERROR", __VA_ARGS__); \
 	cleanup (); \
 	die_finalise (); \
@@ -530,7 +539,7 @@ int cap_get_bound (cap_value_t cap);
 #define assert_not_reached() \
 	do { \
 		die ("%s:%d: Not reached assertion failed in %s", \
-			   __FILE__, __LINE__, __FUNCTION__); \
+			   __FILE__, __LINE__, __func__); \
 	} while (0)
 
 #define type_hex_width(type) \
@@ -860,6 +869,8 @@ void wmappendn (pstring **dest, const char *src, size_t len);
 void wmappendf (pstring **dest, const char *fmt, ...);
 void wmappendva (pstring **dest, const char *fmt, va_list ap);
 
+void pappend (pstring **dest, const pstring *src);
+
 int get_indent (void);
 void inc_indent (void);
 void dec_indent (void);
@@ -879,6 +890,7 @@ void chomp (pstring *str);
 void show_version (void);
 void save_locale (void);
 void restore_locale (void);
+void handle_indent_char (void);
 void init (void);
 void cleanup (void);
 bool in_chroot (void);
@@ -939,6 +951,7 @@ void show_pathconfs (ShowMountType what, const char *dir);
 void show_sizeof (void);
 void show_ranges (void);
 void show_compiler (void);
+void show_libc (void);
 void get_uname (void);
 void show_uname (void);
 void show_all_groups (void);
